<?php

namespace CRM\Controller;

use CRM\Traits\TResponse;
use CRM\Service\InterlocutorService;
use Zeedhi\Framework\DTO\Request;

class InterlocutorController
{
    protected $InterlocutorService;

    use TResponse;

    public function __construct(InterlocutorService $InterlocutorService)
    {
        $this->InterlocutorService = $InterlocutorService;
    }

    /**
     * Retrieves interlocutor data based on lead information.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getInterlocutorBasedOnLead(Request $request): array
    {
        try {
            $data = $this->InterlocutorService->getInterlocutorBasedOnLead($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function getSector() : array
    {
        try {
            $data = $this->InterlocutorService->getSector();
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function getPosition() : array
    {
        try {
            $data = $this->InterlocutorService->getPosition();
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }
}
