<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class CrmTipoRevendaFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getTypeOfResaleFactory()
    {

        $sql = "SELECT TPREV.NRTIPOREVENDA, TPREV.DSTIPOREVENDA, 
                TPREV.CDPRECBASESERV, TPREV.CDMODPGTO, TPREV.NRORG, 
                TPREV.DTINCLUSAO, TPREV.DTULTATU, TPREV.NRORGINCLUSAO, 
                TPREV.CDOPERINCLUSAO, TPREV.NRORGULTATU, TPREV.CDOPERULTATU, 
                TPREV.IDATIVO, PRECBASE.DSPRECBASESERV, MODOPAG.DSMODPGTO 
                FROM CRM_TIPOREVENDA TPREV 
                LEFT JOIN MODPGTO MODOPAG 
                ON TPREV.CDMODPGTO = MODOPAG.CDMODPGTO 
                AND TPREV.NRORG = MODOPAG.NRORG 
                LEFT JOIN FCT_PRECBASESERV PRECBASE 
                ON TPREV.CDPRECBASESERV = PRECBASE.CDPRECBASESERV 
                AND TPREV.NRORG = PRECBASE.NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getDataCommissionsFactory()
    {

        $sql = "SELECT COMISSAO.NRCOMISSAOTPREVENDA, COMISSAO.NRTIPOREVENDA, 
                COMISSAO.CDSERVORCA, COMISSAO.IDTPCOMISSAO, COMISSAO.VRCOMISSAO, 
                COMISSAO.NRORG, COMISSAO.DTINCLUSAO, COMISSAO.DTULTATU, 
                COMISSAO.NRORGINCLUSAO, COMISSAO.CDOPERINCLUSAO, COMISSAO.NRORGULTATU, 
                COMISSAO.CDOPERULTATU, COMISSAO.IDATIVO, SERVORCA.NMSERVORCA 
                FROM CRM_COMISSTPREVENDA COMISSAO 
                LEFT JOIN FCT_SERVICOORCA SERVORCA 
                ON COMISSAO.CDSERVORCA = SERVORCA.CDSERVORCA 
                AND COMISSAO.NRORG = SERVORCA.NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getServiceListFactory()
    {

        $sql = "SELECT CONCAT('Serviço ', NMSERVORCA) 
                AS NMSERVORCA
                FROM FCT_SERVICOORCA
                ORDER BY NMSERVORCA ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getPriceListFactory()
    {

        $sql = "SELECT * FROM FCT_PRECBASESERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getPaymentTermFactory()
    {

        $sql = "SELECT * FROM MODPGTO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertNewResaleTypeFactory($params)
    {
        $sql = "INSERT INTO CRM_TIPOREVENDA (
            NRTIPOREVENDA, DSTIPOREVENDA, CDPRECBASESERV,
            CDMODPGTO, NRORG, DTINCLUSAO,
            DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO,
            NRORGULTATU, CDOPERULTATU, IDATIVO
            ) VALUES (
            :NRTIPOREVENDA, :DSTIPOREVENDA, :CDPRECBASESERV,
            :CDMODPGTO, :NRORG, SYSDATE,
            SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO,
            :NRORGULTATU, :CDOPERULTATU, :IDATIVO
            )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateResaleTypeFactory($params)
    {
        $sql = "UPDATE CRM_TIPOREVENDA
                SET DSTIPOREVENDA = :DSTIPOREVENDA,
                CDPRECBASESERV = :CDPRECBASESERV,
                CDMODPGTO = :CDMODPGTO,
                NRORG = :NRORG,
                DTULTATU = SYSDATE,
                NRORGULTATU = :NRORGULTATU,
                CDOPERULTATU = :CDOPERULTATU,
                IDATIVO = :IDATIVO
                WHERE NRTIPOREVENDA = :NRTIPOREVENDA
                AND NRORG = :NRORG";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteResaleTypeFactory($params)
    {
        $sql = "DELETE FROM CRM_TIPOREVENDA
                WHERE NRTIPOREVENDA = :NRTIPOREVENDA
                AND NRORG = :NRORG";

        $this->connection->executeStatement($sql, $params);
    }
}
