<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class EvolucaoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager  $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getEvolutionTab(array $paramsQuery): array
    {
        try {

            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    'MUNICIPIO.NMMUNICIPIO AS CIDADEINTERLOCUTOR',
                    'ESTADO.NMESTADO AS ESTADOINTERLOCUTOR',
                    'EVOL.CDFILIAL',
                    'EVOL.NRCONTATO',
                    'EVOL.DTHREVOLCONT',
                    'EVOL.CDTIPOCONT',
                    'EVOL.IDSENEVOCONT',
                    'EVOL.IDTPEVOLCONT',
                    'EVOL.CDOPEREVOL',
                    'EVOL.CDMOTIEVOCON',
                    'EVOL.NRORG',
                    'EVOL.DTINCLUSAO',
                    'EVOL.DTULTATU',
                    'EVOL.NRORGINCLUSAO',
                    'EVOL.CDOPERINCLUSAO',
                    'EVOL.NRORGULTATU',
                    'EVOL.CDOPERULTATU',
                    'EVOL.NRRELACIONAPARC',
                    'EVOL.IDANEXOEVOLCONT',
                    'EVOL.TXEVOLCONT',
                    'EVOL.IDATIVO',
                    'EVOL.NRSEQRESULEVOL',
                    'EVOL.NRSEQEVOLCONT',
                    'EVOL.NRSEQCONTATO',
                    'EVOL.IDGERAFATURA',
                    'EVOL.NRSEQFILACONTA',
                    'EVOL.NRSEQINTERLOCUTOR',
                    'EVOL.CRM_NRORGTRAB',
                    'CAND.NRCANDIDATO',
                    'CAND.NRPARCNEGOCIO',
                    'OPER.NMOPERADOR',
                    'MOT.NMMOTIEVOCON',
                    'TIPO.NMTIPOCONT',
                    'REST.DESCRESULEVOL',
                    'FILACONT.CDOPERREAL',
                    'FILACONT.DSFILACONTATO',
                    'FILACONT.NRPRIORFILACONT',
                    'FILACONT.DTPLANFILACONTA',
                    'FILACONT.NRSEQCLASSIFICATAREFA',
                    'OPERTAREFA.NMOPERADOR AS NMOPERADORREAL',
                    'REST.IDGERPROXATIV',
                    'INTER.NMINTERLOCUTOR AS NMINTEVOCONT',
                    'INTER.EMAILINTERLOC',
                    'INTER.NRTELEFONE1',
                    'CLASSTAREFA.DSCLASSIFICATAREFA'
                ])
                ->from('EVOLCONT', 'EVOL')
                ->leftJoin('EVOL', 'CRM_CANDIDATO', 'CAND', 'EVOL.NRSEQCONTATO = CAND.NRSEQCONTATO AND CAND.NRORG = EVOL.NRORG')
                ->leftJoin('EVOL', 'OPERADOR', 'OPER', 'EVOL.CDOPEREVOL = OPER.CDOPERADOR AND EVOL.NRORG = OPER.NRORG')
                ->leftJoin('EVOL', 'MOTIEVOLCONT', 'MOT', 'EVOL.CDMOTIEVOCON = MOT.CDMOTIEVOCON AND EVOL.NRORG = MOT.NRORG')
                ->leftJoin('EVOL', 'CRM_RESULTEVOL', 'REST', 'EVOL.NRSEQRESULEVOL = REST.NRSEQRESULEVOL AND EVOL.NRORG = REST.NRORG')
                ->leftJoin('EVOL', 'TIPOCONT', 'TIPO', 'EVOL.CDTIPOCONT = TIPO.CDTIPOCONT AND EVOL.NRORG = TIPO.NRORG')
                ->leftJoin('EVOL', 'CRM_INTERLOCUTOR', 'INTER', 'INTER.NRSEQINTERLOCUTOR = EVOL.NRSEQINTERLOCUTOR AND INTER.NRORG = EVOL.NRORG')
                ->leftJoin('EVOL', 'ESTADO', 'ESTADO', 'ESTADO.NRORG = INTER.NRORG AND ESTADO.CDPAIS = INTER.CDPAIS AND ESTADO.SGESTADO = INTER.SGESTADO')
                ->leftJoin('EVOL', 'MUNICIPIO', 'MUNICIPIO', 'MUNICIPIO.NRORG = INTER.NRORG AND MUNICIPIO.CDPAIS = INTER.CDPAIS AND MUNICIPIO.SGESTADO = INTER.SGESTADO AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO')
                ->leftJoin('EVOL', 'FILACONTATO', 'FILACONT', 'FILACONT.NRSEQFILACONTA = EVOL.NRSEQFILACONTA AND FILACONT.NRORG = EVOL.NRORG AND FILACONT.IDATIVO = :IDATIVO')
                ->leftJoin('EVOL', 'CRM_CLASSIFICATAREFA', 'CLASSTAREFA', 'FILACONT.NRSEQCLASSIFICATAREFA = CLASSTAREFA.NRSEQCLASSIFICATAREFA')
                ->leftJoin('EVOL', 'OPERADOR', 'OPERTAREFA', 'OPERTAREFA.CDOPERADOR = FILACONT.CDOPERREAL')
                ->where('EVOL.NRORG = :NRORG')
                ->andWhere('EVOL.NRCONTATO = :NRCONTATO')
                ->andWhere('EVOL.NRSEQCONTATO = :NRSEQCONTATO')
                ->andWhere('EVOL.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->orderBy('EVOL.DTHREVOLCONT', 'DESC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsQuery['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('NRCONTATO', $paramsQuery['NRCONTATO']);
            $queryBuilder->setParameter('NRSEQCONTATO', $paramsQuery['NRSEQCONTATO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getContactType($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    "CDTIPOCONT",
                    "NMTIPOCONT",
                    "IDATIVO",
                    "NRORG",
                    "NRORGINCLUSAO",
                    "NRORGULTATU",
                    "CDOPERINCLUSAO",
                    "CDOPERULTATU",
                    "DTINCLUSAO",
                    "DTULTATU"
                ])
                ->from('TIPOCONT', 'TIPO')
                ->where('TIPO.NRORG = :NRORG')
                ->andWhere('TIPO.IDATIVO = :IDATIVO')
                ->orderBy('NMTIPOCONT', 'ASC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getEvolutionReason($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    "MOTEVOL.NRORG",
                    "MOTEVOL.IDATIVO",
                    "MOTEVOL.CDMOTIEVOCON",
                    "MOTEVOL.NMMOTIEVOCON",
                    "MOTEVOL.IDENVIAEMAIL",
                    "MOTEVOL.NMANEXOPADRAO",
                    "MOTEVOL.DSCAMINHOANEXOPADRAO",
                ])
                ->from('MOTIEVOLCONT', 'MOTEVOL')
                ->where('MOTEVOL.NRORG = :NRORG')
                ->andWhere('MOTEVOL.IDATIVO = :IDATIVO')
                ->orderBy('NMMOTIEVOCON', 'ASC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getEvolutionReasonBasedOnOperator($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    "MOTEVOL.CDMOTIEVOCON",
                    "INITCAP(MOTEVOL.NMMOTIEVOCON) AS NMMOTIEVOCON",
                    "MOTEVOL.IDENVIAEMAIL",
                    "MOTEVOL.NMANEXOPADRAO",
                    "MOTEVOL.DSCAMINHOANEXOPADRAO",
                    "MOTEVOL.IDATIVO",
                    "MOTEVOL.NRORG"
                ])
                ->from('MOTIEVOLCONT', 'MOTEVOL')
                ->leftJoin('MOTEVOL', 'CRM_PERFIMOTIEVO', 'PM', 'MOTEVOL.CDMOTIEVOCON = PM.CDMOTIEVOCON AND MOTEVOL.NRORG = PM.NRORG')
                ->leftJoin('MOTEVOL', 'CRM_PERFIOPER', 'PO', 'PM.NRSEQPERFATIV = PO.NRSEQPERFATIV AND MOTEVOL.NRORG = PO.NRORG')
                ->where('PO.CDOPERADOR = :CDOPERADOR')
                ->andWhere('MOTEVOL.NRORG = :NRORG')
                ->andWhere('MOTEVOL.IDATIVO = :IDATIVO')
                ->orderBy('NMMOTIEVOCON', 'ASC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            $queryBuilder->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getResult($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    "RESULTEVOL.NRORG",
                    "RESULTEVOL.IDATIVO",
                    "RESULTEVOL.IDRESULTCASO",
                    "RESULTEVOL.IDGANHAPERDE",
                    "INITCAP(RESULTEVOL.DESCRESULEVOL) AS DESCRESULEVOL",
                    "RESULTEVOL.IDGERPROXATIV",
                    "RESULTEVOL.NRSEQRESULEVOL",
                    "RESULTEVOL.IDRESULTEVOLUCAO",
                    "RESULTEVOL.IDRESULTOPORTUNI",
                ])
                ->from('CRM_RESULTEVOL', 'RESULTEVOL')
                ->leftJoin('RESULTEVOL', 'CRM_PERFIRESULT', 'PR', 'RESULTEVOL.NRSEQRESULEVOL = PR.NRSEQRESULEVOL')
                ->where('RESULTEVOL.NRORG = :NRORG')
                ->andWhere('RESULTEVOL.IDATIVO = :IDATIVO')
                ->orderBy('DESCRESULEVOL', 'ASC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getAttachment($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    "ANEXOCONTATO.NRORG",
                    "ANEXOCONTATO.DSTIPO",
                    "ANEXOCONTATO.IDATIVO",
                    "ANEXOCONTATO.DTULTATU",
                    "ANEXOCONTATO.NRORIGEM",
                    "ANEXOCONTATO.IDORIGEM",
                    "ANEXOCONTATO.NMARQUIVO",
                    "ANEXOCONTATO.DSCAMINHO",
                    "ANEXOCONTATO.VRTAMANHO",
                    "ANEXOCONTATO.DTINCLUSAO",
                    "ANEXOCONTATO.NRORGULTATU",
                    "ANEXOCONTATO.CDOPERULTATU",
                    "ANEXOCONTATO.NRSEQCONTATO",
                    "ANEXOCONTATO.NRORGINCLUSAO",
                    "ANEXOCONTATO.CDOPERINCLUSAO",
                    "ANEXOCONTATO.NRANEXOCONTATO",
                ])
                ->from('CRM_ANEXOCONTATO', 'ANEXOCONTATO')
                ->where('ANEXOCONTATO.NRORG = :NRORG')
                ->andWhere('ANEXOCONTATO.IDATIVO = :IDATIVO')
                ->andWhere('ANEXOCONTATO.NRSEQCONTATO = :NRSEQCONTATO');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            $queryBuilder->setParameter('NRSEQCONTATO', $paramsQuery['NRSEQCONTATO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveNewEvolution(array $paramsQuery): string
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder->insert('EVOLCONT')
                ->values([
                    "IDATIVO"                   => ":IDATIVO",
                    "DTHREVOLCONT"              => ":DTHREVOLCONT",
                    "NRORG"                     => ":NRORG",
                    "CRM_NRORGTRAB"             => ":CRM_NRORGTRAB",
                    "DTHRINCLEVOCONT"           => "SYSDATE",
                    "DTINCLUSAO"                => "SYSDATE",
                    "CDFILIAL"                  => ":CDFILIAL",
                    "NRCONTATO"                 => ":NRCONTATO",
                    "CDOPEREVOL"                => ":CDOPEREVOL",
                    "TXEVOLCONT"                => ":TXEVOLCONT",
                    "DSEVOLCONT"                => ":DSEVOLCONT",
                    "CDTIPOCONT"                => ":CDTIPOCONT",
                    "IDSENEVOCONT"              => ":IDSENEVOCONT",
                    "IDGERAFATURA"              => ":IDGERAFATURA",
                    "IDTPEVOLCONT"              => ":IDTPEVOLCONT",
                    "CDMOTIEVOCON"              => ":CDMOTIEVOCON",
                    "NMINTEVOCONT"              => ":NMINTEVOCONT",
                    "NRSEQCONTATO"              => ":NRSEQCONTATO",
                    "NRSEQEVOLCONT"             => ":NRSEQEVOLCONT",
                    "NRORGINCLUSAO"             => ":NRORGINCLUSAO",
                    "CDOPERINCLUSAO"            => ":CDOPERINCLUSAO",
                    "NRSEQRESULEVOL"            => ":NRSEQRESULEVOL",
                    "NRSEQFILACONTA"            => ":NRSEQFILACONTA",
                    "IDANEXOEVOLCONT"           => ":IDANEXOEVOLCONT",
                    "NRRELACIONAPARC"           => ":NRRELACIONAPARC",
                    "NRSEQINTERLOCUTOR"         => ":NRSEQINTERLOCUTOR",
                ]);

            $queryBuilder->setParameters($paramsQuery);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return "Evolução salva com sucesso!";
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
