<?php

namespace CRM\Service;

use CRM\Factory\CrmTipoRevendaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmTipoRevendaService
{

    protected $CrmTipoRevendaFactory;
    protected $environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $environment, NewCode $newCode, EntityManager $entityManager, CrmTipoRevendaFactory $CrmTipoRevendaFactory)
    {
        $this->CrmTipoRevendaFactory = $CrmTipoRevendaFactory;
        $this->environment           = $environment;
        $this->newCode               = $newCode;
        $this->connection            = $entityManager->getConnection();
    }

    public function getTypeOfResaleService()
    {
        return $this->CrmTipoRevendaFactory->getTypeOfResaleFactory();
    }

    public function getDataCommissionsService($params)
    {
        return $this->CrmTipoRevendaFactory->getDataCommissionsFactory();
    }

    public function getPriceListService()
    {
        return $this->CrmTipoRevendaFactory->getPriceListFactory();
    }

    public function getPaymentTermService()
    {
        return $this->CrmTipoRevendaFactory->getPaymentTermFactory();
    }
    
    public function getServiceListService()
    {
        return $this->CrmTipoRevendaFactory->getServiceListFactory();
    }

    public function saveNewResaleTypeService($rows)
    {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();

        try {

            $nrtiporevenda = $this->newCode->getCodeByTableName("CRM_TIPOREVENDA", $nrorg, 1, 5, false);
            $params = array(
                "NRTIPOREVENDA"  => $nrtiporevenda,
                "IDATIVO"        => $rows["IDATIVO"],
                "CDMODPGTO"      => $rows["CDMODPGTO"],
                "DSTIPOREVENDA"  => $rows["DSTIPOREVENDA"],
                "CDPRECBASESERV" => $rows["CDPRECBASESERV"],
                "NRORG"          => $nrorg,
                "NRORGINCLUSAO"  => $nrorg,
                "NRORGULTATU"    => $nrorg,
                "CDOPERINCLUSAO" => $cdoperador,
                "CDOPERULTATU"   => $cdoperador,
            );

            $this->CrmTipoRevendaFactory->insertNewResaleTypeFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }

    public function updateResaleTypeService($rows)
    {

        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();
        try {

            $params = array(
                "IDATIVO"        => $rows["IDATIVO"],
                "CDMODPGTO"      => $rows["CDMODPGTO"],
                "NRTIPOREVENDA"  => $rows["NRTIPOREVENDA"],
                "DSTIPOREVENDA"  => $rows["DSTIPOREVENDA"],
                "CDPRECBASESERV" => $rows["CDPRECBASESERV"],
                "NRORG"          => $nrorg,
                "NRORGULTATU"    => $nrorg,
                "CDOPERULTATU"   => $cdoperador,
            );

            $this->CrmTipoRevendaFactory->updateResaleTypeFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }
    public function deleteResaleTypeService($rows)
    {

        $nrorg = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
        try {

            $params = array(
                "NRTIPOREVENDA"  => $rows["NRTIPOREVENDA"],
                "NRORG"          => $nrorg,
            );

            $this->CrmTipoRevendaFactory->deleteResaleTypeFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }
}
