<?php

namespace CRM\Service;

use CRM\Factory\EnderecoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class EnderecoService
{
    protected $EnderecoFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, EnderecoFactory $EnderecoFactory)
    {
        $this->newCode                            = $newCode;
        $this->Environment                        = $Environment;
        $this->EnderecoFactory                    = $EnderecoFactory;
        $this->connection                         = $entityManager->getConnection();
    }

    public function getCountry()
    {
        $nrorg = $this->Environment->getNrorg();
        try {
            $params = array(
                "NRORG" => $nrorg,
            );
            return $this->EnderecoFactory->getCountry($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getState($params)
    {
        try {
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $paramsForQuery = array(
                "NRORG" => $this->Environment->getNrorg(),
                "CDPAIS" => $cdpais,
            );

            return $this->EnderecoFactory->getState($paramsForQuery);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getMunicipality($params)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $sgestado = isset($params["SGESTADO"]) ? $params["SGESTADO"] : null;

            $params = array(
                "NRORG"    => $nrorg,
                "CDPAIS"   => $cdpais,
                "SGESTADO" => $sgestado,

            );
            return $this->EnderecoFactory->getMunicipality($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getNeighborhood($params)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $sgestado = isset($params["SGESTADO"]) ? $params["SGESTADO"] : null;
            $cdmunicipio = isset($params["CDMUNICIPIO"]) ? $params["CDMUNICIPIO"] : null;

            $params = array(
                "NRORG"    => $nrorg,
                "CDPAIS"   => $cdpais,
                "SGESTADO" => $sgestado,
                "CDMUNICIPIO" => $cdmunicipio,
            );
            return $this->EnderecoFactory->getNeighborhood($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function findCodeDistrict($parametros)
    {
        return $this->EnderecoFactory->findCodeDistrict($parametros);
    }
}
