<?php

namespace CRM\Service;

use CRM\Factory\InterlocutorFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use CRM\Util\Utilities;

class InterlocutorService
{
    protected $newCode;
    protected $connection;
    protected $InterlocutorFactory;
    protected $Environment;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, InterlocutorFactory $InterlocutorFactory)
    {
        $this->InterlocutorFactory                = $InterlocutorFactory;
        $this->Environment                        = $Environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    /**
     * Retrieves interlocutor data based on lead information.
     *
     * @param array $row The lead data.
     * @return array The interlocutor data.
     * @throws \Exception If an error occurs.
     */
    public function getInterlocutorBasedOnLead(array $row): array
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
                'NRPARCNEGOCIO' => $row['NRPARCNEGOCIO'], // Ensure that NRPARCNEGOCIO is provided
            ];

            return $this->InterlocutorFactory->getInterlocutorBasedOnLead($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getSector(): array
    {
        try {
            // Get the logged organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
            ];

            return $this->InterlocutorFactory->getSector($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getPosition(): array
    {
        try {
            // Get the logged organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
            ];

            return $this->InterlocutorFactory->getPosition($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
