<?php

namespace CRM\Service;

use CRM\Factory\TaskScheduleFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use CRM\Util\Utilities;

class TaskScheduleService
{
    protected $newCode;
    protected $connection;
    protected $TaskScheduleFactory;
    protected $Environment;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, TaskScheduleFactory $TaskScheduleFactory)
    {
        $this->TaskScheduleFactory                = $TaskScheduleFactory;
        $this->Environment                        = $Environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    private function createNewNRSEQFILACONTA($tableName, $nrorg): string
    {
        return $this->newCode->getCodeByTableName($tableName, $nrorg);
    }

    /**
     * Retrieves task schedule data based on lead information.
     *
     * @param array $row The lead data.
     * @return array The task schedule data.
     * @throws \Exception If an error occurs.
     */
    public function getTaskScheduleBasedOnLead(array $row): array
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
                'CRM_NRORGTRAB' => $nrorg,
                'NRSEQCONTATO' => $row['NRSEQCONTATO'], // Ensure that NRSEQCONTATO is provided
            ];

            return $this->TaskScheduleFactory->getTaskScheduleBasedOnLead($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retrieves task classification data.
     *
     * @return array The task classification data.
     * @throws \Exception If an error occurs.
     */
    public function getTaskClassification(): array
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
            ];

            return $this->TaskScheduleFactory->getTaskClassification($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function checkIfThereAreAnyOpenTasks(array $row): array
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'IDATIVO' => 'S',
                'NRORG' => $nrorg,
                'CRM_NRORGTRAB' => $nrorg,
                'NRPARCNEGOCIO' => $row['NRPARCNEGOCIO'],
            ];

            return $this->TaskScheduleFactory->checkIfThereAreAnyOpenTasks($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertLeadEvolNextTask(array $row): string
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();
            $nrseqfilaconta = $this->createNewNRSEQFILACONTA('FILACONTATO', $nrorg);

            // Prepare the query parameters
            $paramsQuery = [
                "DSFILACONTATO"             => $row["DSFILACONTATO"] ?? null,
                "DTPLANFILACONTA"           => $row["DTPLANFILACONTA"] ?? null,
                "CDOPERREAL"                => $row["CDOPERREAL"] ?? null,
                "NRSEQFILACONTA"            => $nrseqfilaconta,
                "NRORG"                     => $nrorg,
                "CRM_NRORGTRAB"             => $nrorg,
                "NRORGINCLUSAO"             => $nrorg,
                "CDOPERINCLUSAO"            => $row["CDOPERREAL"] ?? null,
                "IDATIVO"                   => "S",
                "NRPARCNEGOCIO"             => $row["NRPARCNEGOCIO"] ?? null,
                "NRCONTATO"                 => $row["NRSEQCONTATO"] ?? null,
                "NRPRIORFILACONT"           => $row["NRPRIORFILACONT"] ?? 2,
                "NRSEQCONTATO"              => $row["NRSEQCONTATO"] ?? null,
                "NRSEQCLASSIFICATAREFA"     => $row["NRSEQCLASSIFICATAREFA"] ?? null,
                "NRSEQINTERLOCUTOR"         => $row['NRSEQINTERLOCUTOR'] ?? '',
                "DSEMAILTAREFA"             => $row['EMAILINTERLOC'] ?? '',
                "DSTELEFONETAREFA"          => $row['NRTELEFONE1'] ?? '',
            ];

            $this->TaskScheduleFactory->insertLeadEvolNextTask($paramsQuery);
            return $nrseqfilaconta;
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
