import { Utilities } from '@/util/Utilities';
import {
  Button, DialogService, LoadingService, TextInput,
} from '@zeedhi/common';
import {
  Http, IEventParam, Metadata,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmCargoInterlocController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ CDCARGOINTERLOC: newId, IDATIVO: 'S' }, 'start');
    setTimeout(() => {
      const nameInput = Metadata.getInstance<TextInput>(`NMCARGOINTERLOC_editable_${newId}`);
      nameInput.setFocus();
    }, 100);
  }

  public openFilterCargoInterloc({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public savePositionInterlocutor({ component, event }: IEventParam<TekGrid>) {
    event?.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/savePositionInterlocutor', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public messageConfirmDelete({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmCargoInterlocController.deletePositionInterlocutor');
  }

  public deletePositionInterlocutor() {
    const component = Metadata.getInstance<TekGrid>('tek-grid-cargo_interlocutor_grid');

    LoadingService.show();
    Http.post('/deletePositionInterlocutor', {
      CDGS: component.selectedRows.map((element: any) => element.CDCARGOINTERLOC),
    }).then(() => {
      Utilities.showSuccessMessage();
      component.datasource.get();
    }).catch((error: any) => {
      error.showErrorMessage();
    }).finally(() => {
      component.selectedRows = [];
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
