import { Utilities } from '@/util/Utilities';
import { Button, DialogService, LoadingService } from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmModoReceberInfoController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ NRMODORECEBINFO: newId, IDATIVO: 'S' }, 'start');
  }

  public saveReceiveInfo({ component, event }: IEventParam<TekGrid>) {
    event!.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveReceiveInfo', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public reloadGrid(grid: any) {
    const filterButton = Metadata.getInstance<Button>(`${grid}_refreshButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public dialogdeleteReceiveInfo({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmModoReceberInfoController.deleteReceiveInfo');
  }

  public deleteReceiveInfo() {
    const gridInfo = Metadata.getInstance<TekGrid>('tek_grid_modo_recebe_info_grid');
    LoadingService.show();
    Http.post('/deleteReceiveInfo', {
      NRMODORECEBINFO: (gridInfo.selectedRows.map((element: any) => element.NRMODORECEBINFO)),
    }).then(() => {
      gridInfo.datasource.get();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
